#
# spec file for package perl-Socket
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Socket
Version:        2.029
Release:        1.1
%define cpan_name Socket
Summary:        Networking Constants and Support Functions
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PE/PEVANS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(ExtUtils::Constant) >= 0.23
%{perl_requires}

%description
This module provides a variety of constants, structure manipulators and
other functions related to socket-based networking. The values and
functions provided are useful when used in conjunction with Perl core
functions such as socket(), setsockopt() and bind(). It also provides
several other support functions, mostly for dealing with conversions of
network addresses between human-readable and native binary forms, and for
hostname resolver operations.

Some constants and functions are exported by default by this module; but
for backward-compatibility any recently-added symbols are not exported by
default and must be requested explicitly. When an import list is provided
to the 'use Socket' line, the default exports are not automatically
imported. It is therefore best practice to always to explicitly list all
the symbols required.

Also, some common socket "newline" constants are provided: the constants
'CR', 'LF', and 'CRLF', as well as '$CR', '$LF', and '$CRLF', which map to
'\015', '\012', and '\015\012'. If you do not want to use the literal
characters in your programs, then use the constants provided here. They are
not exported by default, but can be imported individually, and with the
':crlf' export tag:

 use Socket qw(:DEFAULT :crlf);

 $sock->print("GET / HTTP/1.0$CRLF");

The entire getaddrinfo() subsystem can be exported using the tag
':addrinfo'; this exports the getaddrinfo() and getnameinfo() functions,
and all the 'AI_*', 'NI_*', 'NIx_*' and 'EAI_*' constants.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes
%license Artistic Copying LICENSE

%changelog
* Fri Feb 22 2019 coolo@suse.com
- updated to 2.029
  see /usr/share/doc/packages/perl-Socket/Changes
  2.029   2019-02-20 19:19:12
    [BUGFIXES]
  * Old MinGW lacks ADDRESS_FAMILY; use USHORT instead (RT128550)
  2.028   2019-02-19 23:59:30
    [CHANGES]
  * Add PF_LOCAL/AF_LOCAL constants (RT127089)
  * Provide sockaddr_un on WIN32 (RT128550)
* Tue Jan 23 2018 coolo@suse.com
- updated to 2.027
  see /usr/share/doc/packages/perl-Socket/Changes
  2.027   2018-01-12 16:58:47
    [BUGFIXES]
  * Reimplement croak_sv (securely) for older perls (RT124063)
  2.026   2018-01-11 23:15:28
    [CHANGES]
  * Add TCP_USER_TIMEOUT (RT123253)
    [BUGFIXES]
  * Fix printf format specifier for STRLEN/sizeof (RT124044)
  * Recognise %%Config key for HAS_GAI_STRERROR (RT124044)
  * Remove unused and insecure implementation of croak_sv (RT122830)
* Wed Jan 10 2018 coolo@suse.com
- updated to 2.025
  see /usr/share/doc/packages/perl-Socket/Changes
  2.025   2018-01-09 15:12:51
    [CHANGES]
  * Add IPPROTO_ICMPV6
    [BUGFIXES]
  * Fix for C++11 compilers - require a space either side of
    string-pasting macros (thanks Karl Williamson)
  * Fix for machines lacking HAS_SOCKADDR_IN6 (RT116913) (thanks ilmari)
  * Print to STDERR on test failures (RT123436) (thanks ilmari)
* Fri Aug 12 2016 coolo@suse.com
- updated to 2.024
  see /usr/share/doc/packages/perl-Socket/Changes
  2.024   2016/08/11 13:49:48
    [BUGFIXES]
  * Restore back-compat to pre-2.011 behaviour on undefined port
    numbers to pack_sockaddr_in(6?) - silently accept undef as zero
    (RT116699)
  * Warn if pack_sockaddr_un is truncating an overly long path
    (mitigates but does not resolve RT116819)
* Thu Aug  4 2016 coolo@suse.com
- updated to 2.023
  see /usr/share/doc/packages/perl-Socket/Changes
  2.023   2016/08/02 14:50:50
    [CHANGES]
  * Add more socket(7), ip(7) and ipv6(7) socket options from Linux
    [BUGFIXES]
  * Fix skip count for abstract AF_UNIX path tests when not running on
    Linux
* Tue Aug  2 2016 coolo@suse.com
- updated to 2.022
  see /usr/share/doc/packages/perl-Socket/Changes
  2.022   2016/08/01 16:02:48
    [CHANGES]
  * Throw exceptions if pack/unpack sockaddr functions are passed
    undefined arguments (RT116624)
    [BUGFIXES]
  * Fix coverty complaint (RT111707)
* Fri Mar 18 2016 chris@computersalat.de
- initial pkg 2.021
